@@ -2,6 +2,7 @@ from rest_framework.decorators import api_view
 from rest_framework.response import Response
 from server.tasks import run_code
 
+import subprocess
 import pandas as pd
 
 
@@ -10,6 +11,12 @@ def ping(request):
     return Response('pong')
 
 
+@api_view(['POST'])
+def update(request):
+    subprocess.run(["/home/ubuntu/parsagon/parsagon-local-server/bin/parsagon-server-update"])
+    return Response('OK')
+
+
 @api_view(['POST'])
 def read_db(request):
     db_type = request.data['db_type']
